Module exit_code

Module exit_code 

Enumeration representing the various error codes that might be returned by function calls. These error codes are mapped to those defined in the original C TREXIO library.

Enums

ExitCode